@@ -18,18 +18,14 @@ sub close {
   $self->emit('close');
 }
 
-sub close_gracefully {
-  my $self = shift;
-  return $self->{graceful} = 1 if $self->is_writing;
-  $self->close;
-}
+sub close_gracefully { $_[0]->is_writing ? $_[0]{graceful}++ : $_[0]->close }
 
 sub handle { shift->{handle} }
 
 sub is_readable {
   my $self = shift;
   $self->_again;
-  return $self->{handle} && $self->reactor->is_readable($self->{handle});
+  return $self->{handle} && Mojo::Util::_readable(0, fileno $self->{handle});
 }
 
 sub is_writing {
