@@ -7,7 +7,7 @@ use Cwd 'abs_path';
 use File::Basename 'dirname';
 use File::Spec::Functions 'catfile';
 use Mojo::Server::Prefork;
-use Mojo::Util 'steady_time';
+use Mojo::Util qw(deprecated steady_time);
 use Scalar::Util 'weaken';
 
 has prefork => sub { Mojo::Server::Prefork->new };
@@ -22,11 +22,14 @@ sub configure {
   $c->{listen} ||= ['http://*:8080'];
   $self->upgrade_timeout($c->{upgrade_timeout}) if $c->{upgrade_timeout};
 
+  # DEPRECATED in Tiger Face!
+  deprecated 'keep_alive_requests setting is DEPRECATED in favor of requests'
+    if !$c->{requests} && ($c->{requests} ||= $c->{keep_alive_requests});
+
   # Prefork settings
-  $prefork->reverse_proxy($c->{proxy}) if defined $c->{proxy};
-  $prefork->max_clients($c->{clients}) if $c->{clients};
-  $prefork->max_requests($c->{keep_alive_requests})
-    if $c->{keep_alive_requests};
+  $prefork->reverse_proxy($c->{proxy})   if defined $c->{proxy};
+  $prefork->max_clients($c->{clients})   if $c->{clients};
+  $prefork->max_requests($c->{requests}) if $c->{requests};
   defined $c->{$_} and $prefork->$_($c->{$_})
     for qw(accepts backlog graceful_timeout group heartbeat_interval),
     qw(heartbeat_timeout inactivity_timeout listen multi_accept pid_file),
@@ -258,9 +261,10 @@ L<Mojo::Server::Daemon/"backlog">.
 
   clients => 100
 
-Maximum number of concurrent client connections per worker process, defaults
-to the value of L<Mojo::IOLoop/"max_connections">. Note that high concurrency
-works best with applications that perform mostly non-blocking operations, to
+Maximum number of concurrent connections each worker process is allowed to
+handle before stopping to accept new incoming connections, defaults to the
+value of L<Mojo::IOLoop/"max_connections">. Note that high concurrency works
+best with applications that perform mostly non-blocking operations, to
 optimize for blocking operations you can decrease this value and increase
 L</"workers"> instead for better performance.
 
@@ -302,13 +306,6 @@ Maximum amount of time in seconds a connection can be inactive before getting
 closed, defaults to the value of L<Mojo::Server::Daemon/"inactivity_timeout">.
 Setting the value to C<0> will allow connections to be inactive indefinitely.
 
-=head2 keep_alive_requests
-
-  keep_alive_requests => 50
-
-Number of keep-alive requests per connection, defaults to the value of
-L<Mojo::Server::Daemon/"max_requests">.
-
 =head2 listen
 
   listen => ['http://*:80']
@@ -339,6 +336,13 @@ Activate reverse proxy support, which allows for the C<X-Forwarded-For> and
 C<X-Forwarded-Proto> headers to be picked up automatically, defaults to the
 value of L<Mojo::Server/"reverse_proxy">.
 
+=head2 requests
+
+  requests => 50
+
+Number of keep-alive requests per connection, defaults to the value of
+L<Mojo::Server::Daemon/"max_requests">.
+
 =head2 upgrade_timeout
 
   upgrade_timeout => 45
@@ -361,9 +365,9 @@ Number of worker processes, defaults to the value of
 L<Mojo::Server::Prefork/"workers">. A good rule of thumb is two worker
 processes per CPU core for applications that perform mostly non-blocking
 operations, blocking operations often require more and benefit from decreasing
-the number of concurrent L</"clients"> (often as low as C<1>). Note that
-during zero downtime software upgrades there will be twice as many workers
-active for a short amount of time.
+concurrency with L</"clients"> (often as low as C<1>). Note that during zero
+downtime software upgrades there will be twice as many workers active for a
+short amount of time.
 
 =head1 ATTRIBUTES
 
