@@ -2,7 +2,6 @@ package Mojo::Server::Prefork;
 use Mojo::Base 'Mojo::Server::Daemon';
 
 use File::Spec::Functions qw(catfile tmpdir);
-use IO::Poll qw(POLLIN POLLPRI);
 use Mojo::Util qw(deprecated steady_time);
 use POSIX 'WNOHANG';
 use Scalar::Util 'weaken';
@@ -88,8 +87,6 @@ sub run {
 
   # Pipe for worker communication
   pipe($self->{reader}, $self->{writer}) or die "Can't create pipe: $!";
-  $self->{poll} = IO::Poll->new;
-  $self->{poll}->mask($self->{reader}, POLLIN | POLLPRI);
 
   # Clean manager environment
   local $SIG{CHLD} = sub {
@@ -181,7 +178,7 @@ sub _spawn {
   # Clean worker environment
   $SIG{$_} = 'DEFAULT' for qw(CHLD INT TERM TTIN TTOU);
   $SIG{QUIT} = sub { $loop->stop_gracefully };
-  delete @$self{qw(poll reader)};
+  delete $self->{reader};
   srand;
 
   $self->app->log->debug("Worker $$ started");
@@ -209,10 +206,9 @@ sub _wait {
   my $self = shift;
 
   # Poll for heartbeats
-  my $poll = $self->emit('wait')->{poll};
-  $poll->poll(1);
-  return unless $poll->handles(POLLIN | POLLPRI);
-  return unless $self->{reader}->sysread(my $chunk, 4194304);
+  my $reader = $self->emit('wait')->{reader};
+  return unless Mojo::Util::_readable(1000, fileno($reader));
+  return unless $reader->sysread(my $chunk, 4194304);
 
   # Update heartbeats (and stop gracefully if necessary)
   my $time = steady_time;
@@ -448,8 +444,8 @@ Full path of process id file, defaults to a random temporary path.
 Number of worker processes, defaults to C<4>. A good rule of thumb is two
 worker processes per CPU core for applications that perform mostly
 non-blocking operations, blocking operations often require more and benefit
-from decreasing the number of concurrent L<Mojo::Server::Daemon/"clients">
-(often as low as C<1>).
+from decreasing concurrency with L<Mojo::Server::Daemon/"clients"> (often as
+low as C<1>).
 
 =head1 METHODS
 
