@@ -43,7 +43,7 @@ has types     => sub { Mojolicious::Types->new };
 has validator => sub { Mojolicious::Validator->new };
 
 our $CODENAME = 'Tiger Face';
-our $VERSION  = '5.81';
+our $VERSION  = '5.82';
 
 sub AUTOLOAD {
   my $self = shift;
@@ -619,6 +619,8 @@ requests indiscriminately, for a full list of available hooks see L</"HOOKS">.
 =head2 new
 
   my $app = Mojolicious->new;
+  my $app = Mojolicious->new(moniker => 'foo_bar');
+  my $app = Mojolicious->new({moniker => 'foo_bar'});
 
 Construct a new L<Mojolicious> application and call L</"startup">. Will
 automatically detect your home directory and set up logging based on your
