@@ -49,8 +49,14 @@ sub accepts {
   return @exts ? undef : shift;
 }
 
-sub add_handler { shift->_add(handlers => @_) }
-sub add_helper  { shift->_add(helpers  => @_) }
+sub add_handler { $_[0]->handlers->{$_[1]} = $_[2] and return $_[0] }
+
+sub add_helper {
+  my ($self, $name, $cb) = @_;
+  $self->helpers->{$name} = $cb;
+  delete $self->{proxy};
+  return $self;
+}
 
 sub get_data_template {
   my ($self, $options) = @_;
@@ -204,13 +210,6 @@ sub template_path {
   return undef;
 }
 
-sub _add {
-  my ($self, $attr, $name, $cb) = @_;
-  $self->$attr->{$name} = $cb;
-  delete $self->{proxy};
-  return $self;
-}
-
 sub _bundled { $TEMPLATES{"@{[pop]}.html.ep"} }
 
 sub _extends {
@@ -290,7 +289,8 @@ Renderer cache, defaults to a L<Mojo::Cache> object.
   $renderer   = $renderer->classes(['main']);
 
 Classes to use for finding templates in C<DATA> sections with L<Mojo::Loader>,
-first one has the highest precedence, defaults to C<main>.
+first one has the highest precedence, defaults to C<main>. Only files with
+exactly two extensions will be used, like C<index.html.ep>.
 
   # Add another class with templates in DATA section
   push @{$renderer->classes}, 'Mojolicious::Plugin::Fun';
